@@ -52,7 +52,7 @@ from .util import time_to_arlotime
 
 _LOGGER = logging.getLogger("pyaarlo")
 
-__version__ = "0.8.0.11"
+__version__ = "0.8.0.15"
 
 
 class PyArlo(object):
@@ -597,7 +597,7 @@ class PyArlo(object):
 
     @property
     def blank_image(self):
-        """Return a binaryy representation of a blank image.
+        """Return a binary representation of a blank image.
 
         :return: A bytes representation of a blank image.
         :rtype: bytearray
