@@ -320,6 +320,38 @@ class ArloCamera(ArloChildDevice):
         if response is not None:
             self._mark_as_idle()
 
+    def _get_stream_url(self, starting_for, user_agent=None):
+        """Getting the stream URL without starting local streaming."""
+        body = {
+            "action": "get",
+            "from": self.web_id,
+            "properties": {
+                "cameraId": self.device_id,
+            },
+            "publishResponse": True,
+            "responseUrl": "",
+            "resource": self.resource_id,
+            "to": self.parent_id,
+            "transId": self._arlo.be.gen_trans_id(),
+        }
+
+        headers = {"xcloudId": self.xcloud_id}
+        if user_agent is not None:
+            headers["User-Agent"] = self._arlo.be.user_agent(user_agent)
+
+        self._stream_url = self._arlo.be.post(STREAM_START_PATH, body, headers=headers)
+        if self._stream_url is not None:
+            if not self.has_any_local_users:
+                with self._lock:
+                    self._local_users.add(starting_for)
+                    self._dump_activities("_get_stream_url")
+
+            self._stream_url = self._stream_url["url"].replace("rtsp://", "rtsps://")
+            self.debug("url={}".format(self._stream_url))
+        else:
+            self.debug(f"No stream url for {self.name}")
+        return self._stream_url
+
     def _start_stream(self, starting_for, user_agent=None):
         with self._lock:
             # Already streaming. Update sub-activity as needed.
@@ -936,6 +968,11 @@ class ArloCamera(ArloChildDevice):
         if self.was_recently_active:
             return "recently active"
         return super().state
+    
+    def get_stream_url(self, user_agent=None):
+        """Getting the stream URL without starting local streaming."""
+        
+        return self._get_stream_url("remote", user_agent)
 
     def get_stream(self, user_agent=None):
         """Start a stream and return the URL for it.
