@@ -1,5 +1,6 @@
 import platform
 import tempfile
+import os
 from urllib.parse import urlparse
 
 from .constant import (
@@ -36,8 +37,12 @@ class ArloCfg(object):
         self._kw = kwargs
         self._arlo.debug("config: loaded")
         self._update_backend = False
-        if platform.system() == "Windows":
-            self._storage_dir = tempfile.gettempdir() + r"\.aarlo"
+        strplatform = platform.system()
+        termux_dir = "/data/data/com.termux/files/home"
+        if strplatform == "Windows":
+            self._storage_dir = os.path.join(tempfile.gettempdir(), ".aarlo")
+        elif os.path.exists(termux_dir):
+            self._storage_dir = self._kw.get("storage_dir", os.path.join(termux_dir, ".aarlo"))
         else:
             self._storage_dir = self._kw.get("storage_dir", "/tmp/.aarlo")
 
