@@ -4,8 +4,8 @@ from .constant import (
     CHIMES_KEY,
     CONNECTION_KEY,
     MODEL_WIRED_VIDEO_DOORBELL,
-    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
     MODEL_ESSENTIAL_VIDEO_DOORBELL,
     MOTION_DETECTED_KEY,
     SIGNAL_STR_KEY,
@@ -93,8 +93,8 @@ class ArloDoorBell(ArloChildDevice):
     def is_video_doorbell(self):
         return self.model_id.startswith((
             MODEL_WIRED_VIDEO_DOORBELL,
-            MODEL_WIRED_VIDEO_DOORBELL2_HD,
-            MODEL_WIRED_VIDEO_DOORBELL2_2K,
+            MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+            MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
             MODEL_ESSENTIAL_VIDEO_DOORBELL
         ))
 
